@@ -213,6 +213,10 @@ String fallbackResourcesCommon[] = {
     "XMgrace*foreground: #000000",
     "XMgrace*XbaeMatrix.oddRowBackground: #cccccc",
     "XMgrace*XbaeMatrix.evenRowBackground: #cfe7e7",
+    "XMgrace*XbaeMatrix.textBackground: #cfe7e7",
+    "XMgrace*XbaeMatrix.allowColumnResize: False",
+    "XMgrace*XbaeMatrix.allowRowResize: False",
+    "XMgrace*XbaeMatrix.showArrows: True",
     "XMgrace*fontTable.evenRowBackground: #e5e5e5",
     "XMgrace*XmPushButton.background: #b0c4de",
     "XMgrace*XmMenuShell*XmPushButton.background: #e5e5e5",
